Documentation
¶
Index ¶
Constants ¶
const (
CloudConfigKey = "cloud-config"
)
const (
ComponentName = "cloud-controller-manager-kubevirt"
)
Variables ¶
This section is empty.
Functions ¶
func NewComponent ¶
func NewComponent() component.ControlPlaneComponent
Types ¶
type CloudConfig ¶
type CloudConfig struct {
Kubeconfig string `yaml:"kubeconfig"`
LoadBalancer LoadBalancerConfig `yaml:"loadBalancer"`
InstancesV2 InstancesV2Config `yaml:"instancesV2"`
Namespace string `yaml:"namespace"`
InfraLabels map[string]string `yaml:"infraLabels"`
}
Cloud Config is a copy of the relevant subset of the upstream type at https://github.com/kubevirt/cloud-provider-kubevirt/blob/main/pkg/provider/cloud.go
type InstancesV2Config ¶
type LoadBalancerConfig ¶
type LoadBalancerConfig struct {
// Enabled activates the load balancer interface of the CCM
Enabled bool `yaml:"enabled"`
// CreationPollInterval determines how many seconds to wait for the load balancer creation
CreationPollInterval int `yaml:"creationPollInterval"`
// Selectorless delegate endpointslices creation on third party by
// skipping service selector creation
Selectorless *bool `yaml:"selectorless,omitempty"`
}
Click to show internal directories.
Click to hide internal directories.