Documentation
¶
Index ¶
- func NewFilteredOpenshiftEC2NodeClassInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewOpenshiftEC2NodeClassInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type Interface
- type OpenshiftEC2NodeClassInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFilteredOpenshiftEC2NodeClassInformer ¶
func NewFilteredOpenshiftEC2NodeClassInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredOpenshiftEC2NodeClassInformer constructs a new informer for OpenshiftEC2NodeClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewOpenshiftEC2NodeClassInformer ¶
func NewOpenshiftEC2NodeClassInformer(client clientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewOpenshiftEC2NodeClassInformer constructs a new informer for OpenshiftEC2NodeClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type Interface ¶
type Interface interface {
// OpenshiftEC2NodeClasses returns a OpenshiftEC2NodeClassInformer.
OpenshiftEC2NodeClasses() OpenshiftEC2NodeClassInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type OpenshiftEC2NodeClassInformer ¶
type OpenshiftEC2NodeClassInformer interface {
Informer() cache.SharedIndexInformer
Lister() karpenterv1beta1.OpenshiftEC2NodeClassLister
}
OpenshiftEC2NodeClassInformer provides access to a shared informer and lister for OpenshiftEC2NodeClasses.